
#line 2 "ncgenl.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer ncg_create_buffer
#define yy_delete_buffer ncg_delete_buffer
#define yy_scan_buffer ncg_scan_buffer
#define yy_scan_string ncg_scan_string
#define yy_scan_bytes ncg_scan_bytes
#define yy_init_buffer ncg_init_buffer
#define yy_flush_buffer ncg_flush_buffer
#define yy_load_buffer_state ncg_load_buffer_state
#define yy_switch_to_buffer ncg_switch_to_buffer
#define yypush_buffer_state ncgpush_buffer_state
#define yypop_buffer_state ncgpop_buffer_state
#define yyensure_buffer_stack ncgensure_buffer_stack
#define yy_flex_debug ncg_flex_debug
#define yyin ncgin
#define yyleng ncgleng
#define yylex ncglex
#define yylineno ncglineno
#define yyout ncgout
#define yyrestart ncgrestart
#define yytext ncgtext
#define yywrap ncgwrap
#define yyalloc ncgalloc
#define yyrealloc ncgrealloc
#define yyfree ncgfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define ncg_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer ncg_create_buffer
#endif

#ifdef yy_delete_buffer
#define ncg_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer ncg_delete_buffer
#endif

#ifdef yy_scan_buffer
#define ncg_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer ncg_scan_buffer
#endif

#ifdef yy_scan_string
#define ncg_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string ncg_scan_string
#endif

#ifdef yy_scan_bytes
#define ncg_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes ncg_scan_bytes
#endif

#ifdef yy_init_buffer
#define ncg_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer ncg_init_buffer
#endif

#ifdef yy_flush_buffer
#define ncg_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer ncg_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define ncg_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state ncg_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define ncg_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer ncg_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define ncgpush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state ncgpush_buffer_state
#endif

#ifdef yypop_buffer_state
#define ncgpop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state ncgpop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define ncgensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack ncgensure_buffer_stack
#endif

#ifdef yylex
#define ncglex_ALREADY_DEFINED
#else
#define yylex ncglex
#endif

#ifdef yyrestart
#define ncgrestart_ALREADY_DEFINED
#else
#define yyrestart ncgrestart
#endif

#ifdef yylex_init
#define ncglex_init_ALREADY_DEFINED
#else
#define yylex_init ncglex_init
#endif

#ifdef yylex_init_extra
#define ncglex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra ncglex_init_extra
#endif

#ifdef yylex_destroy
#define ncglex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy ncglex_destroy
#endif

#ifdef yyget_debug
#define ncgget_debug_ALREADY_DEFINED
#else
#define yyget_debug ncgget_debug
#endif

#ifdef yyset_debug
#define ncgset_debug_ALREADY_DEFINED
#else
#define yyset_debug ncgset_debug
#endif

#ifdef yyget_extra
#define ncgget_extra_ALREADY_DEFINED
#else
#define yyget_extra ncgget_extra
#endif

#ifdef yyset_extra
#define ncgset_extra_ALREADY_DEFINED
#else
#define yyset_extra ncgset_extra
#endif

#ifdef yyget_in
#define ncgget_in_ALREADY_DEFINED
#else
#define yyget_in ncgget_in
#endif

#ifdef yyset_in
#define ncgset_in_ALREADY_DEFINED
#else
#define yyset_in ncgset_in
#endif

#ifdef yyget_out
#define ncgget_out_ALREADY_DEFINED
#else
#define yyget_out ncgget_out
#endif

#ifdef yyset_out
#define ncgset_out_ALREADY_DEFINED
#else
#define yyset_out ncgset_out
#endif

#ifdef yyget_leng
#define ncgget_leng_ALREADY_DEFINED
#else
#define yyget_leng ncgget_leng
#endif

#ifdef yyget_text
#define ncgget_text_ALREADY_DEFINED
#else
#define yyget_text ncgget_text
#endif

#ifdef yyget_lineno
#define ncgget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno ncgget_lineno
#endif

#ifdef yyset_lineno
#define ncgset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno ncgset_lineno
#endif

#ifdef yywrap
#define ncgwrap_ALREADY_DEFINED
#else
#define yywrap ncgwrap
#endif

#ifdef yyalloc
#define ncgalloc_ALREADY_DEFINED
#else
#define yyalloc ncgalloc
#endif

#ifdef yyrealloc
#define ncgrealloc_ALREADY_DEFINED
#else
#define yyrealloc ncgrealloc
#endif

#ifdef yyfree
#define ncgfree_ALREADY_DEFINED
#else
#define yyfree ncgfree
#endif

#ifdef yytext
#define ncgtext_ALREADY_DEFINED
#else
#define yytext ncgtext
#endif

#ifdef yyleng
#define ncgleng_ALREADY_DEFINED
#else
#define yyleng ncgleng
#endif

#ifdef yyin
#define ncgin_ALREADY_DEFINED
#else
#define yyin ncgin
#endif

#ifdef yyout
#define ncgout_ALREADY_DEFINED
#else
#define yyout ncgout
#endif

#ifdef yy_flex_debug
#define ncg_flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug ncg_flex_debug
#endif

#ifdef yylineno
#define ncglineno_ALREADY_DEFINED
#else
#define yylineno ncglineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 49
#define YY_END_OF_BUFFER 50
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[422] =
    {   0,
        0,    0,   46,   46,    0,    0,   50,   48,    1,   44,
       48,   48,   48,   48,   38,   32,   36,   36,   35,   35,
       35,   35,   35,   35,   35,   48,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   48,   48,   48,   46,   49,   34,   49,    1,
        0,    3,    0,    0,    0,   38,   36,    0,    0,   38,
       38,    0,   39,   45,    2,   32,    0,    0,    0,    0,
       36,   36,   36,   36,    0,   35,    0,    0,    0,    0,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,

       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,    0,    0,   46,    0,   47,   34,   40,
        0,    0,    0,    0,   38,    0,    0,   38,    2,   32,
        0,    0,    0,    0,    0,    0,    0,    4,    0,    0,
       35,   35,   35,   35,   35,   35,   31,   28,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       14,   35,   28,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,    0,   43,    0,    0,   38,

        0,   32,    0,    0,    0,    0,    0,    0,    0,    4,
       37,   37,    0,   35,   35,   29,   35,   35,   30,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   10,    9,   35,   35,   35,   35,    6,   35,
       35,   35,   35,   14,   35,   35,   35,    8,   35,   35,
       35,   35,   35,   15,   35,   35,   35,   35,    0,    0,
       29,    0,   32,    0,    0,    0,    0,    0,    0,    0,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   24,
       35,   35,   35,   16,   35,   35,   35,   35,   12,   35,

       35,   35,   11,   35,   35,   15,   35,   35,   35,   41,
       42,    0,    0,    0,    0,   35,   35,   35,   26,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   18,   25,   35,    7,   19,
        5,   21,   17,   35,   35,   13,   35,    0,    0,   35,
       35,   35,   35,   35,   35,   35,   35,   33,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
        0,   35,   27,   35,   35,   35,   35,   35,   35,   35,
       35,   35,    5,   35,   35,   35,   35,   27,   27,   20,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,

       35,   35,   35,   35,   35,   35,   35,   23,   35,   35,
       35,   22,   35,   35,   35,   35,   35,   35,   35,   35,
        0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    2,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    5,    6,    5,    5,    5,    5,    7,    5,
        5,    8,    9,    5,   10,   11,   12,   13,   14,   15,
       16,   17,   14,   18,   14,   19,   19,   20,    5,    5,
        5,    5,    5,   21,   22,   23,   24,   25,   26,   27,
       28,   28,   29,   28,   28,   30,   31,   32,   28,   33,
       28,   28,   34,   35,   36,   37,   28,   38,   28,   28,
        5,   39,    5,    5,   40,    5,   41,   42,   43,   44,

       45,   46,   47,   48,   49,   28,   50,   51,   52,   53,
       54,   55,   56,   57,   58,   59,   60,   61,   28,   38,
       62,   63,   64,    5,    5,    5,    1,   65,   65,   65,
       65,   65,   65,   65,   65,   65,   65,   65,   65,   65,
       65,   65,   65,   65,   65,   65,   65,   65,   65,   65,
       65,   65,   65,   65,   65,   65,   65,   65,   65,   65,
       65,   65,   65,   65,   65,   65,   65,   65,   65,   65,
       65,   65,   65,   65,   65,   65,   65,   65,   65,   65,
       65,   65,   65,   65,   65,   65,   65,   65,   65,   65,
       65,   66,   66,   66,   66,   66,   66,   66,   66,   66,

       66,   66,   66,   66,   66,   66,   66,   66,   66,   66,
       66,   66,   66,   66,    1,    1,    1,    1,    1,    1,
        1,    1,    1,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   68,
       68,   68,   68,   68,   68,   68,   68,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[69] =
    {   0,
        1,    1,    2,    1,    1,    1,    3,    4,    5,    5,
        6,    7,    8,    8,    8,    8,    8,    8,    8,    1,
        5,    9,    9,    9,    9,   10,    9,   11,   12,   13,
       11,   11,   11,   13,   11,   11,   11,   11,   11,   11,
        9,    9,    9,    9,   10,    9,   11,   11,   11,   11,
       13,   11,   11,   11,   11,   11,   11,   13,   11,   11,
       11,   11,   11,   14,    1,   11,   11,   11
    } ;

static const flex_int16_t yy_base[440] =
    {   0,
        0,    0,  325,  321,  264,  255,  318, 2387,   67, 2387,
       64,  269,   61,   62,   95,   77,  136,  259,   51,   61,
      188,   97,  118,  150,   65,  195,  233,  153,  183,  222,
      241,  202,  207,  213,  238,  246,  243,  257,  268,  264,
      298,  276,  221,  219,  218,  270,  236,    0, 2387,   79,
       87, 2387,  244,  238,  344,    0,  206,  358,  190,    0,
     2387,  370, 2387, 2387,    0,  342,  377,  177,  175,  174,
      200, 2387,   54,  377,    0,  254,  397,  171,  170,  169,
      358,   85,  404,  373,  376,  398,  391,  406,  412,  417,
      421,  428,  432,  451,  454,  443,  473,  476,  486,  489,

      494,  499,  511,  508,  520,  530,  546,  542,  550,  553,
      556,  560,  563,  566,  586,  598,  602,  605,  608,  623,
      612,  644,  647,  168,  167,  222,  217, 2387,    0, 2387,
      221,  680,  219,  703,  710,  179,  728,  749,    0,  691,
      666,  765,  159,  158,  135,  130,  128,  651,  125,  123,
      739,  716,  721,  751,  764,  770,  757,  775,  783,  760,
      794,  800,  806,  809,  813,  824,  820,  844,  839,  830,
      854,  850,  862,  869,  874,  886,  904,  893,  908,  917,
      947,  934,  912,  964,  943,  954,  900,  957,  973,  969,
      987,  990,  995, 1006,  999,  118, 2387,  735,    0, 2387,

       50, 1030, 1062,  117,  115,  112,  110,  108,  104,  904,
       72, 2387,  103, 1020, 1025, 1043, 1046, 1064, 1051, 1069,
     1076, 1055, 1085, 1088, 1099, 1094, 1118, 1102, 1125, 1132,
     1137, 1142, 1149, 1156, 1167, 1162, 1172, 1175, 1179, 1192,
     1197, 1210, 1214, 1205, 1223, 1230, 1227, 1217, 1240, 1247,
     1262, 1253, 1265, 1298, 1278, 1283, 1295, 1301,  160,  154,
     2387,  107, 1314, 1350,   93,   91,   77,   73,   72,   70,
     1332, 1344, 1335, 1320, 1356, 1340, 1352, 1374, 1388, 1391,
     1366, 1396, 1406, 1412, 1409, 1422, 1428, 1442, 1445, 2387,
     1448, 1452, 1462, 1459, 1478, 1465, 1495, 1498, 1482, 1508,

     1501, 1515, 1485, 1519, 1531, 1534, 1540, 1545, 1549, 2387,
     2387,   85,   65,   59,   36, 1564, 1556, 1575, 1553, 1590,
     1571, 1587, 1594, 1609, 1606, 1601, 1612, 1627, 1642, 1645,
     1648, 1651, 1661, 1667, 1682, 1685, 2387, 1697, 1691, 1700,
     1716, 2387, 1703, 1733, 1721, 1707, 1740,   39,   27, 1751,
     1746, 1754, 1770, 1766, 1758, 1788, 1784, 1763, 1800, 1803,
     1814, 1818, 1833, 1807, 1821, 1825, 1837, 1851, 1857, 1867,
       24, 1870, 1874, 1882, 1888, 1892, 1900, 1904, 1908, 1923,
     1938, 1934, 1913, 1943, 1918, 1948, 1954,   36, 1958, 1964,
     1968, 1978, 1989, 1994, 2002, 2010, 1999, 2020, 2013, 2033,

     2025, 2036, 2050, 2059, 2045, 2056, 2070, 2387, 2075, 2089,
     2082, 2387, 2093, 2096, 2100, 2108, 2112, 2132, 2119, 2138,
     2387, 2206, 2220, 2234, 2248, 2257, 2266, 2275, 2288, 2302,
     2315, 2329, 2339, 2345, 2353, 2355, 2361, 2367, 2373
    } ;

static const flex_int16_t yy_def[440] =
    {   0,
      421,    1,  422,  422,  423,  423,  421,  421,  421,  421,
      424,  425,  421,  426,  421,  427,  421,   17,  428,  428,
      428,  428,  428,  428,  428,  421,  428,  428,  428,  428,
       21,  428,  428,  428,  428,  428,  428,  428,  428,  428,
      428,  428,  421,  421,  421,  429,  429,  430,  421,  421,
      424,  421,  424,  421,  431,   15,   17,  421,  421,   15,
      421,  421,  421,  421,  432,  433,  421,  421,  421,  421,
       17,  421,  421,  421,  434,  428,  421,  421,  421,  421,
      428,   21,   21,  428,  428,  428,  428,  428,  428,  428,
      428,  428,  428,  428,  428,  428,  428,  428,  428,  428,

      428,  428,  428,  428,  428,  428,  428,  428,  428,  428,
      428,  428,  428,  428,  428,  428,  428,  428,  428,  428,
      428,  428,  428,  421,  421,  429,  429,  421,  430,  421,
      421,  421,  435,  421,  421,  421,  421,  421,  432,  433,
      436,  421,  421,  421,  421,  421,  421,  437,  421,  421,
      428,  428,  428,  428,  428,  428,  428,  428,  428,  428,
      428,  428,  428,  428,  428,  428,  428,  428,  428,  428,
      428,  428,  428,  428,  428,  428,  428,  428,  428,  428,
      428,  428,  428,  428,  428,  428,  428,  428,  428,  428,
      428,  428,  428,  428,  428,  421,  421,  421,  438,  421,

      421,  439,  421,  421,  421,  421,  421,  421,  421,  437,
      421,  421,  421,  428,  428,  428,  428,  428,  428,  428,
      428,  428,  428,  428,  428,  428,  428,  428,  428,  428,
      428,  428,  428,  428,  428,  428,  428,  428,  428,  428,
      428,  428,  428,  428,  428,  428,  428,  428,  428,  428,
      428,  428,  428,  428,  428,  428,  428,  428,  421,  421,
      421,  421,  439,  421,  421,  421,  421,  421,  421,  421,
      428,  428,  428,  428,  428,  428,  428,  428,  428,  428,
      428,  428,  428,  428,  428,  428,  428,  428,  428,  421,
      428,  428,  428,  428,  428,  428,  428,  428,  428,  428,

      428,  428,  428,  428,  428,  428,  428,  428,  428,  421,
      421,  421,  421,  421,  421,  428,  428,  428,  428,  428,
      428,  428,  428,  428,  428,  428,  428,  428,  428,  428,
      428,  428,  428,  428,  428,  428,  421,  428,  428,  428,
      428,  421,  428,  428,  428,  428,  428,  421,  421,  428,
      428,  428,  428,  428,  428,  428,  428,  428,  428,  428,
      428,  428,  428,  428,  428,  428,  428,  428,  428,  428,
      421,  428,  428,  428,  428,  428,  428,  428,  428,  428,
      428,  428,  428,  428,  428,  428,  428,  421,  428,  428,
      428,  428,  428,  428,  428,  428,  428,  428,  428,  428,

      428,  428,  428,  428,  428,  428,  428,  421,  428,  428,
      428,  421,  428,  428,  428,  428,  428,  428,  428,  428,
        0,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421
    } ;

static const flex_int16_t yy_nxt[2456] =
    {   0,
        8,    9,   10,    9,    8,   11,   12,    8,   13,   14,
       15,   16,   17,   18,   18,   18,   18,   18,   18,    8,
        8,   19,   19,   19,   20,   21,   22,   19,   23,   19,
       19,   24,   19,   19,   19,   25,   19,   19,   26,   27,
       19,   28,   29,   30,   31,   32,   33,   19,   34,   19,
       35,   19,   36,   37,   19,   19,   38,   39,   40,   41,
       42,   19,   19,    8,    8,   43,   44,   45,   50,   52,
       50,   56,   56,   57,   57,   57,   57,   57,   57,   57,
       50,  261,   50,   72,   64,  388,   58,   58,   65,   77,
       59,  263,   52,   76,   76,  261,   90,  371,  262,   77,

      202,  212,   53,   77,   72,   58,   58,   60,   60,   60,
       60,   60,   60,   60,   81,   67,   78,   79,   80,   61,
       62,   63,  212,  349,   61,   53,   78,   79,   80,  263,
       78,   79,   80,  348,  140,   77,  315,  202,   61,   62,
       63,  314,   68,   69,   70,   61,   56,   84,   71,   71,
       71,   71,   71,   71,   71,  313,   77,  263,   72,  312,
      311,   58,   78,   79,   80,   73,  310,   76,   66,   72,
       85,   74,  270,   75,  140,   86,  269,   72,   87,  268,
       58,  202,   91,   78,   79,   80,   73,  213,   77,   76,
       88,   77,  209,   72,   66,   74,   82,   82,   89,  208,

       83,   83,   83,   83,   83,   83,   83,   91,   91,   91,
       91,   91,   91,   91,   99,   78,   79,   80,   78,   79,
       80,   77,  207,  140,  201,  197,   77,  197,  421,  127,
      100,  196,   91,  150,  149,   76,  101,  421,  147,  146,
       77,   66,  136,  421,  130,   77,  421,  128,   78,   79,
       80,   77,  106,   78,   79,   80,   92,   93,   94,   95,
       77,   96,  102,  107,   97,  108,   98,   78,   79,   80,
      103,   77,   78,   79,   80,  104,   77,  127,   78,   79,
       80,   77,  125,  124,   77,   91,  110,   78,   79,   80,
      111,  109,   77,  105,  112,   77,  421,  113,   78,   79,

       80,  114,   77,   78,   79,   80,   77,   55,   78,   79,
       80,   78,   79,   80,   77,  115,  123,  421,   49,   78,
       79,   80,   78,   79,   80,  117,  116,   49,   47,   78,
       79,   80,   47,   78,   79,   80,   77,  421,  421,  118,
      421,   78,   79,   80,  421,  421,  119,  421,  120,  421,
      121,  421,  421,  141,  421,  122,  132,  132,  132,  132,
      132,  132,  421,   78,   79,   80,  134,  134,  421,  421,
      135,  135,  135,  135,  135,  135,  135,  421,  137,  137,
      142,  133,  138,  138,  138,  138,  138,  138,  138,   66,
       66,   66,   66,   66,   66,   66,   77,  421,  421,   72,

       76,   76,   76,   76,   76,  421,   73,  143,  144,  145,
       72,   77,   76,   76,   77,  421,   76,  151,   72,  421,
      157,  155,  421,   78,   79,   80,  154,   73,  152,   77,
      153,  421,  156,  152,   72,   76,   77,  158,   78,   79,
       80,   78,   79,   80,   77,  421,  159,  152,  421,  153,
       77,  421,  421,  421,  152,   77,   78,   79,   80,   77,
       76,  421,  157,   78,   79,   80,   77,  421,  421,  421,
       77,   78,   79,   80,  421,  160,  161,   78,   79,   80,
      421,   77,   78,   79,   80,  421,   78,   79,   80,   77,
      421,  421,   77,   78,   79,   80,  167,   78,   79,   80,

      166,  421,  163,  162,  164,  421,  421,  165,   78,   79,
       80,   77,  421,  421,   77,  421,   78,   79,   80,   78,
       79,   80,  421,  169,   77,  421,  168,   77,  421,  173,
      421,  421,   77,  421,  170,  171,  421,   77,   78,   79,
       80,   78,   79,   80,  172,  174,   77,  421,  421,   77,
      421,   78,   79,   80,   78,   79,   80,  175,   77,   78,
       79,   80,  176,  421,   78,   79,   80,  177,   77,  421,
      421,  421,  421,   78,   79,   80,   78,   79,   80,  178,
       77,  421,  421,  179,   77,   78,   79,   80,   77,  421,
      421,   77,  421,  421,   77,   78,   79,   80,   77,  180,

      181,   77,  182,  185,   77,  183,  186,   78,   79,   80,
      157,   78,   79,   80,  184,   78,   79,   80,   78,   79,
       80,   78,   79,   80,   77,   78,   79,   80,   78,   79,
       80,   78,   79,   80,  421,  421,   77,  421,  421,  187,
       77,  421,  421,   77,  421,  421,   77,  421,  421,  421,
       77,   78,   79,   80,  188,  421,  189,  421,  421,  421,
      191,   77,  193,   78,   79,   80,  190,   78,   79,   80,
       78,   79,   80,   78,   79,   80,  192,   78,   79,   80,
      211,  421,   77,  421,  212,   77,  197,  421,   78,   79,
       80,  194,  198,  198,  198,  198,  198,  198,  421,  421,

      421,  211,  141,  195,  203,  421,  421,  421,  212,   78,
       79,   80,   78,   79,   80,  135,  135,  135,  135,  135,
      135,  135,  135,  135,  135,  135,  135,  135,  135,  142,
      421,  204,  205,  206,  200,  421,   63,  421,  421,  200,
      138,  138,  138,  138,  138,  138,  138,  259,  259,  259,
      259,  259,  259,  200,   77,   63,  143,  144,  145,   77,
      200,  138,  138,  138,  138,  138,  138,  138,  140,  140,
      140,  140,  140,   61,  421,   63,  421,   77,   61,  421,
      214,   78,   79,   80,  140,  421,   78,   79,   80,   77,
      421,  215,   61,  218,   63,   77,  421,  421,   77,   61,

      421,  421,   77,  140,   78,   79,   80,  421,   77,  216,
      421,  220,  217,   77,  421,  421,   78,   79,   80,  221,
      219,   77,   78,   79,   80,   78,   79,   80,  140,   78,
       79,   80,   77,  421,  421,   78,   79,   80,   77,  222,
       78,   79,   80,  223,   77,  421,  421,   77,   78,   79,
       80,   77,  228,  225,  421,  227,  224,  421,   77,   78,
       79,   80,   77,  421,  421,   78,   79,   80,   77,  226,
      229,   78,   79,   80,   78,   79,   80,   77,   78,   79,
       80,  421,   77,  231,  421,   78,   79,   80,   77,   78,
       79,   80,   77,  421,  233,   78,   79,   80,  230,  421,

       77,  421,  421,  421,   78,   79,   80,   77,  232,   78,
       79,   80,   77,  421,  236,   78,   79,   80,  234,   78,
       79,   80,  421,  235,   77,  421,  421,   78,   79,   80,
      237,   77,  421,  211,   78,   79,   80,  212,   77,   78,
       79,   80,   77,  421,  239,  238,   77,  421,  240,  421,
       77,   78,   79,   80,  211,   77,  249,  219,   78,   79,
       80,  212,  421,  421,  242,   78,   79,   80,  421,   78,
       79,   80,   77,   78,   79,   80,  241,   78,   79,   80,
      244,   77,   78,   79,   80,   77,  421,  245,  421,  421,
      421,  243,   77,  421,  421,   77,  421,  421,  247,   78,

       79,   80,   77,  421,  248,  250,  246,   77,   78,   79,
       80,   77,   78,   79,   80,  421,  251,  252,  421,   78,
       79,   80,   78,   79,   80,   77,  421,  253,   77,   78,
       79,   80,  421,   77,   78,   79,   80,   77,   78,   79,
       80,  141,  255,  256,   77,  254,  421,  258,  421,  421,
      421,  421,   78,   79,   80,   78,   79,   80,   77,  257,
       78,   79,   80,   77,   78,   79,   80,  421,  264,  421,
      271,   78,   79,   80,  202,  202,  202,  202,  202,  202,
      202,   77,  421,  272,   77,   78,   79,   80,  274,   77,
       78,   79,   80,   77,  421,  265,  266,  267,  273,  275,

      421,  421,   77,  421,  421,  277,  421,   77,   78,   79,
       80,   78,   79,   80,   77,  421,   78,   79,   80,  421,
       78,   79,   80,   77,  421,  421,   77,  421,  276,   78,
       79,   80,   77,  278,   78,   79,   80,   77,  279,  421,
       77,   78,   79,   80,  421,  282,  280,  421,  421,  421,
       78,   79,   80,   78,   79,   80,   77,  281,  284,   78,
       79,   80,  283,   77,   78,   79,   80,   78,   79,   80,
       77,  421,  421,  285,  421,   77,  421,  286,  421,  421,
       77,  290,  421,   78,   79,   80,  288,   77,  421,  421,
       78,   79,   80,  287,   77,  421,  421,   78,   79,   80,

       77,  421,   78,   79,   80,   77,  421,   78,   79,   80,
       77,  421,  421,   77,   78,   79,   80,   77,  421,  421,
      289,   78,   79,   80,  291,  292,  294,   78,   79,   80,
       77,  421,   78,   79,   80,   77,  421,   78,   79,   80,
       78,   79,   80,   77,   78,   79,   80,  296,   77,  421,
      248,  293,   77,  421,  421,   77,  421,   78,   79,   80,
      295,   77,   78,   79,   80,   77,  421,  421,   77,  421,
       78,   79,   80,  297,  421,   78,   79,   80,   77,   78,
       79,   80,   78,   79,   80,   77,  298,  421,   78,   79,
       80,   77,   78,   79,   80,   78,   79,   80,  299,  300,

       77,  421,  421,   77,  301,   78,   79,   80,  421,  303,
      302,  421,   78,   79,   80,  304,   77,  421,   78,   79,
       80,   77,  421,  421,  306,  141,  421,   78,   79,   80,
       78,   79,   80,   77,  307,  421,   77,  421,  421,   77,
      421,  309,  305,   78,   79,   80,  319,  421,   78,   79,
       80,  308,  264,  263,  263,  263,  263,  263,   77,  421,
       78,   79,   80,   78,   79,   80,   78,   79,   80,  263,
       77,  421,  317,   77,  421,  421,  316,  421,   77,  265,
      266,  267,   77,  318,  320,   78,   79,   80,  263,  321,
       77,  421,  322,  421,   77,  421,  421,   78,   79,   80,

       78,   79,   80,  421,   77,   78,   79,   80,  326,   78,
       79,   80,   77,  263,  323,  421,  421,   78,   79,   80,
      421,   78,   79,   80,  324,  421,   77,  421,  421,   77,
      421,   78,   79,   80,   77,  325,  327,  421,  421,   78,
       79,   80,  421,  421,   77,  421,  421,   77,  421,  421,
       77,  421,  421,   78,   79,   80,   78,   79,   80,  330,
       77,   78,   79,   80,  328,  329,   77,  331,  332,  421,
      421,   78,   79,   80,   78,   79,   80,   78,   79,   80,
       77,  337,  421,   77,  421,  421,   77,   78,   79,   80,
       77,  319,  421,   78,   79,   80,  336,   77,  333,  421,

       77,  421,  421,   77,  334,  335,  421,   78,   79,   80,
       78,   79,   80,   78,   79,   80,   77,   78,   79,   80,
       77,  421,  338,   77,   78,   79,   80,   78,   79,   80,
       78,   79,   80,   77,  342,  343,   77,  421,  421,   77,
      319,  421,  339,   78,   79,   80,   77,   78,   79,   80,
       78,   79,   80,   77,  340,  421,  421,   77,  421,  341,
       78,   79,   80,   78,   79,   80,   78,   79,   80,   77,
      421,  421,   77,   78,   79,   80,  421,  344,   77,  421,
       78,   79,   80,   77,   78,   79,   80,   77,  345,  421,
      347,   77,  350,  421,   77,  421,   78,   79,   80,   78,

       79,   80,   77,  346,  354,   78,   79,   80,  351,   77,
       78,   79,   80,   77,   78,   79,   80,  421,   78,   79,
       80,   78,   79,   80,  353,   77,  421,  421,   77,   78,
       79,   80,   77,  352,  421,  421,   78,   79,   80,   77,
       78,   79,   80,  421,   77,  355,  356,   77,  359,  357,
       77,  421,   78,   79,   80,   78,   79,   80,  421,   78,
       79,   80,  358,  421,  421,   77,   78,   79,   80,  360,
      358,   78,   79,   80,   78,   79,   80,   78,   79,   80,
       77,  421,  421,   77,  421,  421,   77,  421,  421,   77,
      421,  421,   78,   79,   80,  358,  361,  363,  362,   77,

      421,  421,  364,  421,  421,   77,  421,   78,   79,   80,
       78,   79,   80,   78,   79,   80,   78,   79,   80,  365,
       77,  421,  421,   77,  421,  421,   78,   79,   80,   77,
      366,  421,   78,   79,   80,   77,  421,  421,   77,  421,
      421,   77,  421,  421,  421,   77,  421,   78,   79,   80,
       78,   79,   80,  244,   77,  421,   78,   79,   80,   77,
      421,  421,   78,   79,   80,   78,   79,   80,   78,   79,
       80,   77,   78,   79,   80,  367,  421,  368,   77,  369,
      421,   78,   79,   80,   77,  421,   78,   79,   80,   77,
      370,  216,   77,  421,  421,  374,   77,  421,   78,   79,

       80,   77,  376,  372,   77,   78,   79,   80,   77,  421,
      421,   78,   79,   80,  375,  373,   78,   79,   80,   78,
       79,   80,   77,   78,   79,   80,   77,  421,   78,   79,
       80,   78,   79,   80,  378,   78,   79,   80,   77,  421,
      377,   77,  421,  421,  379,   77,  380,  421,  421,   78,
       79,   80,   77,   78,   79,   80,   77,  382,  381,   77,
      421,  421,  358,   77,  383,   78,   79,   80,   78,   79,
       80,   77,   78,   79,   80,   77,  421,  358,  384,   78,
       79,   80,  421,   78,   79,   80,   78,   79,   80,   77,
       78,   79,   80,  385,  421,   77,  421,  421,   78,   79,

       80,  386,   78,   79,   80,   77,  390,  306,   77,  421,
      421,  387,   77,  421,  421,  389,   78,   79,   80,  216,
       77,  392,   78,   79,   80,  421,   77,  421,  421,  421,
       77,  421,   78,   79,   80,   78,   79,   80,   77,   78,
       79,   80,   77,  421,  393,  421,   77,   78,   79,   80,
      391,   77,  421,   78,   79,   80,   77,   78,   79,   80,
      421,   77,  383,  394,  395,   78,   79,   80,  396,   78,
       79,   80,   77,   78,   79,   80,   77,  421,   78,   79,
       80,   77,  421,   78,   79,   80,   77,  398,   78,   79,
       80,  390,   77,  421,  397,  399,   77,  421,  421,   78,

       79,   80,   77,   78,   79,   80,   77,  421,   78,   79,
       80,  400,  401,   78,   79,   80,   77,  404,  421,   78,
       79,   80,  402,   78,   79,   80,  358,   77,  421,   78,
       79,   80,   77,   78,   79,   80,  421,   77,  358,  421,
       77,  421,  421,   78,   79,   80,  403,  421,   77,  421,
      421,   77,  408,  421,   78,   79,   80,  405,   77,   78,
       79,   80,  406,   77,   78,   79,   80,   78,   79,   80,
      407,   77,  421,  358,   77,   78,   79,   80,   78,   79,
       80,  421,  358,   77,  421,   78,   79,   80,   77,  412,
       78,   79,   80,  410,   77,  421,  409,   77,   78,   79,

       80,   78,   79,   80,  421,  411,  421,  358,   77,  421,
       78,   79,   80,   77,  421,   78,   79,   80,  415,  413,
       77,   78,   79,   80,   78,   79,   80,   77,  421,  421,
      421,   77,  421,  414,   77,   78,   79,   80,   77,  421,
       78,   79,   80,  358,  416,  421,   77,   78,   79,   80,
       77,  421,  421,  358,   78,   79,   80,   77,   78,   79,
       80,   78,   79,   80,  417,   78,   79,   80,  421,  418,
       77,  421,  420,   78,   79,   80,   77,   78,   79,   80,
      419,  421,  421,  421,   78,   79,   80,  421,  421,  421,
      358,  421,  421,  421,  421,  421,  421,   78,   79,   80,

      421,  421,  421,   78,   79,   80,   46,   46,   46,   46,
       46,   46,   46,   46,   46,   46,   46,   46,   46,   46,
       48,   48,   48,   48,   48,   48,   48,   48,   48,   48,
       48,   48,   48,   48,   51,   51,   51,   51,   51,   51,
       51,   51,   51,   51,   51,   51,   51,   51,   54,   54,
       54,   54,   54,   54,   54,   54,   54,   54,   54,   54,
       54,   54,   57,  421,   57,  421,   57,  421,   57,   66,
      421,  421,   66,  421,   66,   66,   66,   66,   66,   76,
       76,  421,   76,   76,   76,   76,   76,   76,  126,  126,
      126,  126,  126,  126,  126,  126,  126,  126,  126,  126,

      126,  126,  129,  129,  129,  129,  129,  129,  129,  129,
      129,  129,  129,  129,  129,  131,  421,  131,  131,  131,
      131,  131,  131,  131,  131,  131,  131,  131,  131,  139,
      421,  139,  139,  139,  139,  139,  139,  139,  139,  139,
      139,  139,  139,  140,  140,  140,  140,  140,  140,  140,
      140,  140,  148,  148,  148,  199,  421,  421,  421,  421,
      199,  199,  199,  202,  202,  202,  202,  202,  210,  210,
      210,  421,  421,  210,  260,  260,  260,  263,  263,  263,
      263,  263,  263,  263,  263,  263,    7,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,

      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421
    } ;

static const flex_int16_t yy_chk[2456] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    9,   11,
        9,   13,   14,   13,   13,   13,   13,   13,   13,   13,
       50,  388,   50,   73,   16,  371,   13,   14,   16,   19,
       14,  349,   51,   82,   82,  201,   25,  348,  201,   20,

      315,  211,   11,   25,   73,   13,   14,   15,   15,   15,
       15,   15,   15,   15,   20,   16,   19,   19,   19,   15,
       15,   15,  211,  314,   15,   51,   20,   20,   20,  313,
       25,   25,   25,  312,  270,   22,  269,  268,   15,   15,
       15,  267,   16,   16,   16,   15,   17,   22,   17,   17,
       17,   17,   17,   17,   17,  266,   23,  265,   17,  262,
      260,   17,   22,   22,   22,   17,  259,  213,  209,   17,
       23,   17,  208,   17,  207,   24,  206,   17,   24,  205,
       17,  204,  196,   23,   23,   23,   17,  150,   24,  149,
       24,   28,  147,   17,  146,   17,   21,   21,   24,  145,

       21,   21,   21,   21,   21,   21,   21,   26,   26,   26,
       26,   26,   26,   26,   28,   24,   24,   24,   28,   28,
       28,   29,  144,  143,  136,  133,   21,  131,  127,  126,
       29,  125,  124,   80,   79,   78,   29,   71,   70,   69,
       32,   68,   59,   57,   54,   33,   53,   47,   29,   29,
       29,   34,   32,   21,   21,   21,   27,   27,   27,   27,
       30,   27,   30,   33,   27,   34,   27,   32,   32,   32,
       30,   27,   33,   33,   33,   30,   35,   46,   34,   34,
       34,   37,   45,   44,   36,   43,   36,   30,   30,   30,
       36,   35,   76,   31,   36,   38,   18,   37,   27,   27,

       27,   38,   40,   35,   35,   35,   39,   12,   37,   37,
       37,   36,   36,   36,   42,   39,   42,    7,    6,   76,
       76,   76,   38,   38,   38,   40,   39,    5,    4,   40,
       40,   40,    3,   39,   39,   39,   41,    0,    0,   41,
        0,   42,   42,   42,    0,    0,   41,    0,   41,    0,
       41,    0,    0,   66,    0,   41,   55,   55,   55,   55,
       55,   55,    0,   41,   41,   41,   58,   58,    0,    0,
       58,   58,   58,   58,   58,   58,   58,    0,   62,   62,
       66,   55,   62,   62,   62,   62,   62,   62,   62,   67,
       67,   67,   67,   67,   67,   67,   81,    0,    0,   74,

       77,   77,   77,   77,   77,    0,   74,   66,   66,   66,
       74,   84,   83,   83,   85,    0,   77,   81,   74,    0,
       87,   85,    0,   81,   81,   81,   84,   74,   83,   87,
       83,    0,   86,   83,   74,   77,   86,   88,   84,   84,
       84,   85,   85,   85,   88,    0,   90,   83,    0,   83,
       89,    0,    0,    0,   83,   90,   87,   87,   87,   91,
       77,    0,   89,   86,   86,   86,   92,    0,    0,    0,
       93,   88,   88,   88,    0,   92,   93,   89,   89,   89,
        0,   96,   90,   90,   90,    0,   91,   91,   91,   94,
        0,    0,   95,   92,   92,   92,   97,   93,   93,   93,

       96,    0,   95,   94,   95,    0,    0,   95,   96,   96,
       96,   97,    0,    0,   98,    0,   94,   94,   94,   95,
       95,   95,    0,   98,   99,    0,   97,  100,    0,  100,
        0,    0,  101,    0,   98,   98,    0,  102,   97,   97,
       97,   98,   98,   98,   99,  101,  104,    0,    0,  103,
        0,   99,   99,   99,  100,  100,  100,  102,  105,  101,
      101,  101,  103,    0,  102,  102,  102,  104,  106,    0,
        0,    0,    0,  104,  104,  104,  103,  103,  103,  105,
      108,    0,    0,  106,  107,  105,  105,  105,  109,    0,
        0,  110,    0,    0,  111,  106,  106,  106,  112,  107,

      108,  113,  109,  113,  114,  110,  114,  108,  108,  108,
      112,  107,  107,  107,  111,  109,  109,  109,  110,  110,
      110,  111,  111,  111,  115,  112,  112,  112,  113,  113,
      113,  114,  114,  114,    0,    0,  116,    0,    0,  115,
      117,    0,    0,  118,    0,    0,  119,    0,    0,    0,
      121,  115,  115,  115,  116,    0,  117,    0,    0,    0,
      119,  120,  121,  116,  116,  116,  118,  117,  117,  117,
      118,  118,  118,  119,  119,  119,  120,  121,  121,  121,
      148,    0,  122,    0,  148,  123,  132,    0,  120,  120,
      120,  122,  132,  132,  132,  132,  132,  132,    0,    0,

        0,  148,  140,  123,  141,    0,    0,    0,  148,  122,
      122,  122,  123,  123,  123,  134,  134,  134,  134,  134,
      134,  134,  135,  135,  135,  135,  135,  135,  135,  140,
        0,  141,  141,  141,  135,    0,  135,    0,    0,  135,
      137,  137,  137,  137,  137,  137,  137,  198,  198,  198,
      198,  198,  198,  135,  152,  135,  140,  140,  140,  153,
      135,  138,  138,  138,  138,  138,  138,  138,  142,  142,
      142,  142,  142,  138,    0,  138,    0,  151,  138,    0,
      151,  152,  152,  152,  142,    0,  153,  153,  153,  154,
        0,  154,  138,  156,  138,  157,    0,    0,  160,  138,

        0,    0,  155,  142,  151,  151,  151,    0,  156,  155,
        0,  159,  155,  158,    0,    0,  154,  154,  154,  160,
      158,  159,  157,  157,  157,  160,  160,  160,  142,  155,
      155,  155,  161,    0,    0,  156,  156,  156,  162,  161,
      158,  158,  158,  162,  163,    0,    0,  164,  159,  159,
      159,  165,  167,  164,    0,  166,  163,    0,  167,  161,
      161,  161,  166,    0,    0,  162,  162,  162,  170,  165,
      168,  163,  163,  163,  164,  164,  164,  169,  165,  165,
      165,    0,  168,  170,    0,  167,  167,  167,  172,  166,
      166,  166,  171,    0,  172,  170,  170,  170,  169,    0,

      173,    0,    0,    0,  169,  169,  169,  174,  171,  168,
      168,  168,  175,    0,  175,  172,  172,  172,  173,  171,
      171,  171,    0,  174,  176,    0,    0,  173,  173,  173,
      176,  178,    0,  210,  174,  174,  174,  210,  187,  175,
      175,  175,  177,    0,  178,  177,  179,    0,  179,    0,
      183,  176,  176,  176,  210,  180,  187,  183,  178,  178,
      178,  210,    0,    0,  181,  187,  187,  187,    0,  177,
      177,  177,  182,  179,  179,  179,  180,  183,  183,  183,
      182,  185,  180,  180,  180,  181,    0,  184,    0,    0,
        0,  181,  186,    0,    0,  188,    0,    0,  185,  182,

      182,  182,  184,    0,  186,  188,  184,  190,  185,  185,
      185,  189,  181,  181,  181,    0,  188,  189,    0,  186,
      186,  186,  188,  188,  188,  191,    0,  190,  192,  184,
      184,  184,    0,  193,  190,  190,  190,  195,  189,  189,
      189,  202,  192,  193,  194,  191,    0,  195,    0,    0,
        0,    0,  191,  191,  191,  192,  192,  192,  214,  194,
      193,  193,  193,  215,  195,  195,  195,    0,  202,    0,
      214,  194,  194,  194,  203,  203,  203,  203,  203,  203,
      203,  216,    0,  215,  217,  214,  214,  214,  218,  219,
      215,  215,  215,  222,    0,  202,  202,  202,  217,  220,

        0,    0,  218,    0,    0,  222,    0,  220,  216,  216,
      216,  217,  217,  217,  221,    0,  219,  219,  219,    0,
      222,  222,  222,  223,    0,    0,  224,    0,  221,  218,
      218,  218,  226,  223,  220,  220,  220,  225,  224,    0,
      228,  221,  221,  221,    0,  226,  224,    0,    0,    0,
      223,  223,  223,  224,  224,  224,  227,  225,  228,  226,
      226,  226,  227,  229,  225,  225,  225,  228,  228,  228,
      230,    0,    0,  229,    0,  231,    0,  230,    0,    0,
      232,  236,    0,  227,  227,  227,  232,  233,    0,    0,
      229,  229,  229,  231,  234,    0,    0,  230,  230,  230,

      236,    0,  231,  231,  231,  235,    0,  232,  232,  232,
      237,    0,    0,  238,  233,  233,  233,  239,    0,    0,
      235,  234,  234,  234,  237,  238,  242,  236,  236,  236,
      240,    0,  235,  235,  235,  241,    0,  237,  237,  237,
      238,  238,  238,  244,  239,  239,  239,  245,  242,    0,
      240,  241,  243,    0,    0,  248,    0,  240,  240,  240,
      243,  245,  241,  241,  241,  247,    0,    0,  246,    0,
      244,  244,  244,  246,    0,  242,  242,  242,  249,  243,
      243,  243,  248,  248,  248,  250,  247,    0,  245,  245,
      245,  252,  247,  247,  247,  246,  246,  246,  249,  250,

      251,    0,    0,  253,  251,  249,  249,  249,    0,  253,
      252,    0,  250,  250,  250,  254,  255,    0,  252,  252,
      252,  256,    0,    0,  255,  263,    0,  251,  251,  251,
      253,  253,  253,  257,  256,    0,  254,    0,    0,  258,
        0,  258,  254,  255,  255,  255,  274,    0,  256,  256,
      256,  257,  263,  264,  264,  264,  264,  264,  274,    0,
      257,  257,  257,  254,  254,  254,  258,  258,  258,  264,
      271,    0,  272,  273,    0,    0,  271,    0,  276,  263,
      263,  263,  272,  273,  275,  274,  274,  274,  264,  276,
      277,    0,  277,    0,  275,    0,    0,  271,  271,  271,

      273,  273,  273,    0,  281,  276,  276,  276,  281,  272,
      272,  272,  278,  264,  278,    0,    0,  277,  277,  277,
        0,  275,  275,  275,  279,    0,  279,    0,    0,  280,
        0,  281,  281,  281,  282,  280,  282,    0,    0,  278,
      278,  278,    0,    0,  283,    0,    0,  285,    0,    0,
      284,    0,    0,  279,  279,  279,  280,  280,  280,  285,
      286,  282,  282,  282,  283,  284,  287,  286,  287,    0,
        0,  283,  283,  283,  285,  285,  285,  284,  284,  284,
      288,  293,    0,  289,    0,    0,  291,  286,  286,  286,
      292,  296,    0,  287,  287,  287,  292,  294,  288,    0,

      293,    0,    0,  296,  289,  291,    0,  288,  288,  288,
      289,  289,  289,  291,  291,  291,  295,  292,  292,  292,
      299,    0,  295,  303,  294,  294,  294,  293,  293,  293,
      296,  296,  296,  297,  302,  304,  298,    0,    0,  301,
      297,    0,  298,  295,  295,  295,  300,  299,  299,  299,
      303,  303,  303,  302,  300,    0,    0,  304,    0,  301,
      297,  297,  297,  298,  298,  298,  301,  301,  301,  305,
        0,    0,  306,  300,  300,  300,    0,  305,  307,    0,
      302,  302,  302,  308,  304,  304,  304,  309,  307,    0,
      309,  319,  316,    0,  317,    0,  305,  305,  305,  306,

      306,  306,  316,  308,  321,  307,  307,  307,  317,  321,
      308,  308,  308,  318,  309,  309,  309,    0,  319,  319,
      319,  317,  317,  317,  320,  322,    0,    0,  320,  316,
      316,  316,  323,  318,    0,    0,  321,  321,  321,  326,
      318,  318,  318,    0,  325,  322,  323,  324,  326,  324,
      327,    0,  322,  322,  322,  320,  320,  320,    0,  323,
      323,  323,  325,    0,    0,  328,  326,  326,  326,  328,
      327,  325,  325,  325,  324,  324,  324,  327,  327,  327,
      329,    0,    0,  330,    0,    0,  331,    0,    0,  332,
        0,    0,  328,  328,  328,  330,  329,  332,  331,  333,

        0,    0,  333,    0,    0,  334,    0,  329,  329,  329,
      330,  330,  330,  331,  331,  331,  332,  332,  332,  334,
      335,    0,    0,  336,    0,    0,  333,  333,  333,  339,
      335,    0,  334,  334,  334,  338,    0,    0,  340,    0,
        0,  343,    0,    0,    0,  346,    0,  335,  335,  335,
      336,  336,  336,  338,  341,    0,  339,  339,  339,  345,
        0,    0,  338,  338,  338,  340,  340,  340,  343,  343,
      343,  344,  346,  346,  346,  341,    0,  344,  347,  345,
        0,  341,  341,  341,  351,    0,  345,  345,  345,  350,
      347,  351,  352,    0,    0,  353,  355,    0,  344,  344,

      344,  358,  355,  350,  354,  347,  347,  347,  353,    0,
        0,  351,  351,  351,  354,  352,  350,  350,  350,  352,
      352,  352,  357,  355,  355,  355,  356,    0,  358,  358,
      358,  354,  354,  354,  357,  353,  353,  353,  359,    0,
      356,  360,    0,    0,  359,  364,  360,    0,    0,  357,
      357,  357,  361,  356,  356,  356,  362,  364,  361,  365,
        0,    0,  362,  366,  365,  359,  359,  359,  360,  360,
      360,  363,  364,  364,  364,  367,    0,  363,  366,  361,
      361,  361,    0,  362,  362,  362,  365,  365,  365,  368,
      366,  366,  366,  367,    0,  369,    0,    0,  363,  363,

      363,  369,  367,  367,  367,  370,  374,  368,  372,    0,
        0,  370,  373,    0,    0,  372,  368,  368,  368,  373,
      374,  376,  369,  369,  369,    0,  375,    0,    0,    0,
      376,    0,  370,  370,  370,  372,  372,  372,  377,  373,
      373,  373,  378,    0,  377,    0,  379,  374,  374,  374,
      375,  383,    0,  375,  375,  375,  385,  376,  376,  376,
        0,  380,  385,  378,  379,  377,  377,  377,  380,  378,
      378,  378,  382,  379,  379,  379,  381,    0,  383,  383,
      383,  384,    0,  385,  385,  385,  386,  382,  380,  380,
      380,  386,  387,    0,  381,  384,  389,    0,    0,  382,

      382,  382,  390,  381,  381,  381,  391,    0,  384,  384,
      384,  387,  391,  386,  386,  386,  392,  395,    0,  387,
      387,  387,  392,  389,  389,  389,  396,  393,    0,  390,
      390,  390,  394,  391,  391,  391,    0,  397,  394,    0,
      395,    0,    0,  392,  392,  392,  393,    0,  396,    0,
        0,  399,  400,    0,  393,  393,  393,  397,  398,  394,
      394,  394,  398,  401,  397,  397,  397,  395,  395,  395,
      399,  400,    0,  404,  402,  396,  396,  396,  399,  399,
      399,    0,  401,  405,    0,  398,  398,  398,  403,  407,
      401,  401,  401,  405,  406,    0,  402,  404,  400,  400,

      400,  402,  402,  402,    0,  406,    0,  403,  407,    0,
      405,  405,  405,  409,    0,  403,  403,  403,  411,  409,
      411,  406,  406,  406,  404,  404,  404,  410,    0,    0,
        0,  413,    0,  410,  414,  407,  407,  407,  415,    0,
      409,  409,  409,  413,  415,    0,  416,  411,  411,  411,
      417,    0,    0,  414,  410,  410,  410,  419,  413,  413,
      413,  414,  414,  414,  416,  415,  415,  415,    0,  417,
      418,    0,  419,  416,  416,  416,  420,  417,  417,  417,
      418,    0,    0,    0,  419,  419,  419,    0,    0,    0,
      420,    0,    0,    0,    0,    0,    0,  418,  418,  418,

        0,    0,    0,  420,  420,  420,  422,  422,  422,  422,
      422,  422,  422,  422,  422,  422,  422,  422,  422,  422,
      423,  423,  423,  423,  423,  423,  423,  423,  423,  423,
      423,  423,  423,  423,  424,  424,  424,  424,  424,  424,
      424,  424,  424,  424,  424,  424,  424,  424,  425,  425,
      425,  425,  425,  425,  425,  425,  425,  425,  425,  425,
      425,  425,  426,    0,  426,    0,  426,    0,  426,  427,
        0,    0,  427,    0,  427,  427,  427,  427,  427,  428,
      428,    0,  428,  428,  428,  428,  428,  428,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,

      429,  429,  430,  430,  430,  430,  430,  430,  430,  430,
      430,  430,  430,  430,  430,  431,    0,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  432,
        0,  432,  432,  432,  432,  432,  432,  432,  432,  432,
      432,  432,  432,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  434,  434,  434,  435,    0,    0,    0,    0,
      435,  435,  435,  436,  436,  436,  436,  436,  437,  437,
      437,    0,    0,  437,  438,  438,  438,  439,  439,  439,
      439,  439,  439,  439,  439,  439,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,

      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "ncgen.l"
#line 2 "ncgen.l"
/*********************************************************************
 *   Copyright 1993, UCAR/Unidata
 *   See netcdf/COPYRIGHT file for copying and redistribution conditions.
 *   $Id: ncgen.l,v 1.24 2009/09/25 18:22:35 dmh Exp $
 *********************************************************************/

/* Problems:
1. We assume the input is true utf8.
   Unfortunately, we may actually get iso-latin-8859-1.
   This means that there will be ambiguity about the characters
   in the range 128-255 because they will look like n-byte unicode
   when they are 1-byte 8859 characters. Because of our encoding,
   8859 characters above 128 will be handles as n-byte utf8 and so
   will probably not lex correctly.
   Solution: assume utf8 and note in the documentation that
   ISO8859 is specifically unsupported.
2. The netcdf function NC_check_name in string.c must be modified to
   conform to the use of UTF8.
3. We actually have three tests for UTF8 of increasing correctness
   (in the sense that the least correct will allow some sequences that
    are technically illegal UTF8).
   The tests are derived from the table at
	    http://www.w3.org/2005/03/23-lex-U
   We include lexical definitions for all three, but use the second version.
4. Single character constants enclosed in '...' cannot be
   utf-8, so we assume they are by default encoded using the 1-byte
   subset of utf-8. It turns out that this subset is in fact
   equivalent to US-Ascii (7-bit).
   We could use ISO-8859-1, but that conflicts with UTF-8 above value 127.
*/

/* lex specification for tokens for ncgen */

/* Fill value used by ncdump from version 2.4 and later.  Should match
   definition of FILL_STRING in ../ncdump/vardata.h */

#include "ncgen.h"
#include "ncgeny.h"

#define FILL_STRING "_"
#define XDR_INT32_MIN (-2147483647-1)
#define XDR_INT32_MAX 2147483647
#define XDR_INT64_MIN  (-9223372036854775807LL-1)
#define XDR_INT64_MAX  (9223372036854775807LL)

#undef DEBUG
#ifdef DEBUG
static int MIN_BYTE = NC_MIN_BYTE;
static int MIN_SHORT = NC_MIN_SHORT;
static int MIN_INT = NC_MIN_INT;
static int MAX_BYTE = NC_MAX_BYTE;
static int MAX_SHORT = NC_MAX_SHORT;
static int MAX_INT = NC_MAX_INT;
static int MAX_UBYTE = NC_MAX_UBYTE;
static int MAX_USHORT = NC_MAX_USHORT;
static unsigned int MAX_UINT = NC_MAX_UINT;

#undef NC_MIN_BYTE
#undef NC_MIN_SHORT
#undef NC_MIN_INT
#undef NC_MAX_BYTE
#undef NC_MAX_SHORT
#undef NC_MAX_INT
#undef NC_MAX_UBYTE
#undef NC_MAX_USHORT
#undef NC_MAX_UINT

#define NC_MIN_BYTE MIN_BYTE
#define NC_MIN_SHORT MIN_SHORT
#define NC_MIN_INT MIN_INT
#define NC_MAX_BYTE MAX_BYTE
#define NC_MAX_SHORT MAX_SHORT
#define NC_MAX_INT MAX_INT
#define NC_MAX_UBYTE MAX_UBYTE
#define NC_MAX_USHORT MAX_USHORT
#define NC_MAX_UINT MAX_UINT
#endif

#define TAGCHARS "BbSsLlUu"

#define tstdecimal(ch) ((ch) >= '0' && (ch) <= '9')

/*Mnemonics*/
#define ISIDENT 1

/* Define a fake constant indicating that
   no tag was specified */
#define NC_NOTAG (-1)

char errstr[100];		/* for short error messages */

int lineno;              /* line number for error messages */
Bytebuffer* lextext;           /* name or string with escapes removed */

#define YY_BREAK                /* defining as nothing eliminates unreachable
				   statement warnings from flex output,
                                   but make sure every action ends with
                                   "return" or "break"! */

int specialconstants;		/* 1 if nan, nanf, infinity, etc is used */
double double_val;             /* last double value read */
float float_val;               /* last float value read */
long long int64_val;           /* last int64 value read */
int int32_val;                 /* last int32 value read */
short int16_val;               /* last short value read */
unsigned long long uint64_val; /* last int64 value read */
unsigned int uint32_val;       /* last int32 value read */
unsigned short uint16_val;     /* last short value read */
char char_val;                 /* last char value read */
signed char byte_val;                 /* last byte value read */
unsigned char ubyte_val;       /* last byte value read */

static Symbol* makepath(char* text);
static int lexdebug(int);
static unsigned long long parseULL(char* text, int*);
static nc_type downconvert(unsigned long long uint64, int*, int, int);
static int tagmatch(nc_type nct, int tag);
static int nct2lexeme(nc_type nct);
static int collecttag(char* text, char** stagp);

struct Specialtoken specials[] = {
{"_FillValue",_FILLVALUE,_FILLVALUE_FLAG},
{"_Format",_FORMAT,_FORMAT_FLAG},
{"_Storage",_STORAGE,_STORAGE_FLAG},
{"_ChunkSizes",_CHUNKSIZES,_CHUNKSIZES_FLAG},
{"_Fletcher32",_FLETCHER32,_FLETCHER32_FLAG},
{"_DeflateLevel",_DEFLATELEVEL,_DEFLATE_FLAG},
{"_Shuffle",_SHUFFLE,_SHUFFLE_FLAG},
{"_Endianness",_ENDIANNESS,_ENDIAN_FLAG},
{"_NoFill",_NOFILL,_NOFILL_FLAG},
{"_NCProperties",_NCPROPS,_NCPROPS_FLAG},
{"_IsNetcdf4",_ISNETCDF4,_ISNETCDF4_FLAG},
{"_SuperblockVersion",_SUPERBLOCK,_SUPERBLOCK_FLAG},
{"_Filter",_FILTER,_FILTER_FLAG},
{NULL,0} /* null terminate */
};

#line 1521 "ncgenl.c"

/* The most correct (validating) version of UTF8 character set
   (Taken from: http://www.w3.org/2005/03/23-lex-U)

The lines of the expression cover the UTF8 characters as follows:
1. non-overlong 2-byte
2. excluding overlongs
3. straight 3-byte
4. excluding surrogates
5. straight 3-byte
6. planes 1-3
7. planes 4-15
8. plane 16

UTF8   ([\xC2-\xDF][\x80-\xBF])                       \
     | (\xE0[\xA0-\xBF][\x80-\xBF])                   \
     | ([\xE1-\xEC][\x80-\xBF][\x80-\xBF])            \
     | (\xED[\x80-\x9F][\x80-\xBF])                   \
     | ([\xEE-\xEF][\x80-\xBF][\x80-\xBF])            \
     | (\xF0[\x90-\xBF][\x80-\xBF][\x80-\xBF])        \
     | ([\xF1-\xF3][\x80-\xBF][\x80-\xBF][\x80-\xBF]) \
     | (\xF4[\x80-\x8F][\x80-\xBF][\x80-\xBF])        \

*/
/* Wish there was some way to ifdef lex files */
/*The most relaxed version of UTF8 (not used)
UTF8 ([\xC0-\xD6].)|([\xE0-\xEF]..)|([\xF0-\xF7]...)
*/
/*The partially relaxed version of UTF8, and the one used here */
/* The old definition of ID
ID ([A-Za-z_]|{UTF8})([A-Z.@#\[\]a-z_0-9+-]|{UTF8})*
*/
/* Don't permit control characters or '/' in names, but other special
   chars OK if escaped.  Note that to preserve backwards
   compatibility, none of the characters _.@+- should be escaped, as
   they were previously permitted in names without escaping.  */
/* New definition to conform to a subset of string.c */
/* Capture a datasetidentifier */
/* DATASETID ([a-zA-Z0-9!#$%&*:;<=>?/^|~_.@+-]|{UTF8})* */
/* Note: this definition of string will work for utf8 as well,
   although it is a very relaxed definition
*/
#line 1564 "ncgenl.c"

#define INITIAL 0
#define ST_C_COMMENT 1
#define TEXT 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 218 "ncgen.l"

#line 1785 "ncgenl.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 422 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 2387 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 219 "ncgen.l"
{ /* whitespace */
		  break;
		}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 223 "ncgen.l"
{ /* comment */
                          break;
                        }
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 227 "ncgen.l"
{int len;
			 /* In netcdf4, this will be used in a variety
                            of places, so only remove escapes */
/*
if(yyleng > MAXTRST) {
yyerror("string too long, truncated\n");
yytext[MAXTRST-1] = '\0';
}
*/
		        /* FIX: Assumes unescape also does normalization */
			bbSetalloc(lextext,yyleng+1); /*+1 for nul */
			/* Adjust length */
		        bbSetlength(lextext,yyleng-2); /*-2 for quotes */
			len = unescape(bbContents(lextext),
                                       (char *)yytext+1,yyleng-2,!ISIDENT);
			if(len < 0) {
			    sprintf(errstr,"Illegal character: %s",yytext);
			    yyerror(errstr);
			}
			bbSetlength(lextext,len);
			bbNull(lextext);
		 	return lexdebug(TERMSTRING);
		        }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 251 "ncgen.l"
{ /* drop leading 0x; pad to even number of chars */
		char* p = yytext+2;
		int len = yyleng - 2;
		bbClear(lextext);
	        bbAppendn(lextext,p,len);
	        if((len % 2) == 1) bbAppend(lextext,'0');
		bbNull(lextext);
		/* convert all chars to lower case */
		for(p=bbContents(lextext);(int)*p;p++) *p = tolower(*p);
		return lexdebug(OPAQUESTRING);
		}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 263 "ncgen.l"
{return lexdebug(COMPOUND);}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 264 "ncgen.l"
{return lexdebug(ENUM);}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 265 "ncgen.l"
{return lexdebug(OPAQUE_);}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 267 "ncgen.l"
{return lexdebug(FLOAT_K);}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 268 "ncgen.l"
{return lexdebug(CHAR_K);}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 269 "ncgen.l"
{return lexdebug(BYTE_K);}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 270 "ncgen.l"
{return lexdebug(UBYTE_K);}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 271 "ncgen.l"
{return lexdebug(SHORT_K);}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 272 "ncgen.l"
{return lexdebug(USHORT_K);}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 273 "ncgen.l"
{return lexdebug(INT_K);}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 274 "ncgen.l"
{return lexdebug(UINT_K);}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 275 "ncgen.l"
{return lexdebug(INT64_K);}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 276 "ncgen.l"
{return lexdebug(UINT64_K);}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 277 "ncgen.l"
{return lexdebug(DOUBLE_K);}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 278 "ncgen.l"
{return lexdebug(STRING_K);}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 280 "ncgen.l"
{int32_val = -1;
			 return lexdebug(NC_UNLIMITED_K);}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 283 "ncgen.l"
{return lexdebug(TYPES);}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 284 "ncgen.l"
{return lexdebug(DIMENSIONS);}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 285 "ncgen.l"
{return lexdebug(VARIABLES);}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 286 "ncgen.l"
{return lexdebug(DATA);}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 287 "ncgen.l"
{return lexdebug(GROUP);}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 289 "ncgen.l"
{BEGIN(TEXT);return lexdebug(NETCDF);}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 291 "ncgen.l"
{ /* missing value (pre-2.4 backward compatibility) */
                if (yytext[0] == '-') {
		    double_val = NEGNC_INFINITE;
                } else {
		    double_val = NC_INFINITE;
                }
		specialconstants = 1;
		return lexdebug(DOUBLE_CONST);
		}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 300 "ncgen.l"
{ /* missing value (pre-2.4 backward compatibility) */
		double_val = NAN;
		specialconstants = 1;
		return lexdebug(DOUBLE_CONST);
		}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 306 "ncgen.l"
{/* missing value (pre-2.4 backward compatibility)*/
                if (yytext[0] == '-') {
		    float_val = NEGNC_INFINITEF;
                } else {
		    float_val = NC_INFINITEF;
                }
		specialconstants = 1;
		return lexdebug(FLOAT_CONST);
		}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 315 "ncgen.l"
{ /* missing value (pre-2.4 backward compatibility) */
		float_val = NANF;
		specialconstants = 1;
		return lexdebug(FLOAT_CONST);
		}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 321 "ncgen.l"
{
#ifdef USE_NETCDF4
		if(l_flag == L_C || l_flag == L_BINARY)
		    return lexdebug(NIL);
		yyerror("NIL only allowed for netcdf-4 and for -lc or -lb");
#else
		yyerror("NIL only allowed for netcdf-4 and for -lc or -lb");
#endif
		}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 331 "ncgen.l"
{
		bbClear(lextext);
		bbAppendn(lextext,(char*)yytext,yyleng+1); /* include null */
	        bbNull(lextext);
		yylval.sym = makepath(bbContents(lextext));
		return lexdebug(PATH);
		}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 340 "ncgen.l"
{struct Specialtoken* st;
		bbClear(lextext);
		bbAppendn(lextext,(char*)yytext,yyleng+1); /* include null */
		bbNull(lextext);
		for(st=specials;st->name;st++) {
		    if(strcmp(bbContents(lextext),st->name)==0) {return lexdebug(st->token);}
		}
		return 0;
		}
	YY_BREAK
case 34:
/* rule 34 can match eol */
YY_RULE_SETUP
#line 350 "ncgen.l"
{
		    int c;
		    char* p; char* q;
		    /* copy the trimmed name */
		    bbClear(lextext);
		    bbAppendn(lextext,(char*)yytext,yyleng+1); /* include null */
		    bbNull(lextext);
		    p = bbContents(lextext);
		    q = p;
		    while((c=*p++)) {if(c > ' ') *q++ = c;}
		    *q = '\0';
		    if(datasetname == NULL)
		        datasetname = bbDup(lextext);
		    BEGIN(INITIAL);
		    return lexdebug(DATASETID);
		}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 367 "ncgen.l"
{ char* id; int len;
		    bbClear(lextext);
		    bbAppendn(lextext,(char*)yytext,yyleng+1); /* include null */
		    bbNull(lextext);
		    id = bbContents(lextext);
		    len = unescape(id,id,bbLength(lextext),ISIDENT);
		    bbSetlength(lextext,len);
		    if (STREQ(id, FILL_STRING)) return lexdebug(FILLMARKER);
		    yylval.sym = install(id);
		    return lexdebug(IDENT);
		}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 379 "ncgen.l"
{
		/*
		  We need to try to see what size of integer ((u)int).
		  Technically, the user should specify, but...
		  If out of any integer range, then complain
		*/
		    int slen = strlen(ncgtext);
		    char* stag = NULL;
		    int tag = NC_NAT;
		    int isneg = 0;
		    int c = ncgtext[0];
		    int fail = 0;
		    nc_type nct = 0;
		    char* pos = NULL;
		    int hasU = 0;

		    /* capture the tag string */
		    tag = collecttag(ncgtext,&stag);
		    if(tag == NC_NAT) {
			sprintf(errstr,"Illegal integer suffix: %s",stag);
			yyerror(errstr);
			goto done;
		    }
		    /* drop the tag from the input text */
		    ncgtext[slen - strlen(stag)] = '\0';
		    hasU = isuinttype(tag);
		    if(!tstdecimal(c)) {
			pos = ncgtext+1;
			isneg = (c == '-');
		    } else
		        pos = ncgtext;
		    if(isneg && hasU) {
			sprintf(errstr,"Unsigned integer cannot be signed: %s",ncgtext);
			yyerror(errstr);
			goto done;
		    }
		    uint64_val = parseULL(pos,&fail);
		    if(fail) {
			sprintf(errstr,"integer constant out of range: %s",ncgtext);
			yyerror(errstr);
			goto done;
		    }
		    /* Down convert to smallest possible range */
		    nct = downconvert(uint64_val,&tag,isneg,hasU);
		    switch (k_flag) {
		    case NC_FORMAT_64BIT_DATA:
		    case NC_FORMAT_NETCDF4:
			    return lexdebug(nct2lexeme(nct));
		    case NC_FORMAT_CLASSIC:
		    case NC_FORMAT_64BIT_OFFSET:
		    case NC_FORMAT_NETCDF4_CLASSIC:
			    if(nct > NC_INT) {
				sprintf(errstr,"Illegal integer constant for classic format: %s",ncgtext);
				yyerror(errstr);
				goto done;
			    }
		    }

		    if(!tagmatch(nct,tag))  {
			semwarn(lineno,"Warning: Integer out of range for tag: %s; tag treated as changed.",ncgtext);
		    }
		    return lexdebug(nct2lexeme(nct));
done: return 0;
	    }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 444 "ncgen.l"
{
		int c;
		int token = 0;
		int slen = strlen(yytext);
		char* stag = NULL;
	        int tag = NC_NAT;
		char* hex = yytext+2; /* point to first true hex digit */
		int xlen = (slen - 3);  /* true hex length */

		yytext[slen-1] = '\0';
	        /* capture the tag string */
		tag = collecttag(yytext,&stag);
		if(tag == NC_NAT) {
		    sprintf(errstr,"Illegal integer suffix: %s",stag);
		    yyerror(errstr);
		    goto done;
		}
		yytext[slen - strlen(stag)] = '\0';
	        if(xlen > 16) { /* truncate hi order digits */
		    hex += (xlen - 16);
		}
		/* convert to an unsigned long long */
		uint64_val = 0;
		while((c=*hex++)) {
		    unsigned int hexdigit = (c <= '9'?(c-'0'):(c-'a')+0xa);
		    uint64_val = ((uint64_val << 4) | hexdigit);
		}
		switch (tag) {
		case NC_USHORT:
		    uint16_val = (unsigned short)uint64_val;
		    token = USHORT_CONST;
		    break;
		case NC_UINT:
		    token = UINT_CONST;
		    break;
		case NC_UINT64:
		    token = UINT64_CONST;
		    break;
		default: /* should never happen */
		    if (sscanf((char*)yytext, "%i", &uint32_val) != 1) {
		        sprintf(errstr,"bad unsigned int constant: %s",(char*)yytext);
		        yyerror(errstr);
		    }
		    token = UINT_CONST;
		}
		return lexdebug(token);
	    }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 491 "ncgen.l"
{
		if (sscanf((char*)yytext, "%le", &double_val) != 1) {
		    sprintf(errstr,"bad long or double constant: %s",(char*)yytext);
		    yyerror(errstr);
		}
                return lexdebug(DOUBLE_CONST);
                }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 498 "ncgen.l"
{
		if (sscanf((char*)yytext, "%e", &float_val) != 1) {
		    sprintf(errstr,"bad float constant: %s",(char*)yytext);
		    yyerror(errstr);
		}
                return lexdebug(FLOAT_CONST);
                }
	YY_BREAK
case 40:
/* rule 40 can match eol */
YY_RULE_SETUP
#line 505 "ncgen.l"
{
	        (void) sscanf((char*)&yytext[1],"%c",&byte_val);
		return lexdebug(BYTE_CONST);
                }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 509 "ncgen.l"
{
		int oct = unescapeoct(&yytext[2]);
		if(oct < 0) {
		    sprintf(errstr,"bad octal character constant: %s",(char*)yytext);
		    yyerror(errstr);
		}
	        byte_val = (unsigned int)oct;
		return lexdebug(BYTE_CONST);
                }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 518 "ncgen.l"
{
		int hex = unescapehex(&yytext[3]);
		if(byte_val < 0) {
		    sprintf(errstr,"bad hex character constant: %s",(char*)yytext);
		    yyerror(errstr);
		}
		byte_val = (unsigned int)hex;
		return lexdebug(BYTE_CONST);
                }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 527 "ncgen.l"
{
	       switch ((char)yytext[2]) {
	          case 'a': byte_val = '\007'; break; /* not everyone under-
						       * stands '\a' yet */
     	          case 'b': byte_val = '\b'; break;
		  case 'f': byte_val = '\f'; break;
		  case 'n': byte_val = '\n'; break;
		  case 'r': byte_val = '\r'; break;
		  case 't': byte_val = '\t'; break;
		  case 'v': byte_val = '\v'; break;
		  case '\\': byte_val = '\\'; break;
		  case '?': byte_val = '\177'; break;
		  case '\'': byte_val = '\''; break;
		  default: byte_val = (char)yytext[2];
	           }
		return lexdebug(BYTE_CONST);
                }
	YY_BREAK
case 44:
/* rule 44 can match eol */
YY_RULE_SETUP
#line 545 "ncgen.l"
{
		lineno++ ;
                break;
		}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 550 "ncgen.l"
{/*initial*/
	    BEGIN(ST_C_COMMENT);
	    break;
	}
	YY_BREAK
case 46:
/* rule 46 can match eol */
YY_RULE_SETUP
#line 555 "ncgen.l"
{/* continuation */
				     break;
				}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 559 "ncgen.l"
{/* final */
			    BEGIN(INITIAL);
			    break;
			}
	YY_BREAK
case YY_STATE_EOF(ST_C_COMMENT):
#line 564 "ncgen.l"
{/* final, error */
			    fprintf(stderr,"unterminated /**/ comment");
			    BEGIN(INITIAL);
			    break;
			}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 570 "ncgen.l"
{/* Note: this next rule will not work for UTF8 characters */
		return lexdebug(yytext[0]) ;
		}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 573 "ncgen.l"
ECHO;
	YY_BREAK
#line 2377 "ncgenl.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(TEXT):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 422 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 422 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 421);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 573 "ncgen.l"

static int
lexdebug(int token)
{
    if(debug >= 2)
    {
	char* text = yytext;
	text[yyleng] = 0;
        fprintf(stderr,"Token=%d |%s| line=%d\n",token,text,lineno);
    }
    return token;
}

int
lex_init(void)
{
    lineno = 1;
    lextext = bbNew();
    if(0) unput(0); /* keep -Wall quiet */
    return 0;
}

static Symbol*
makepath(char* text0)
{
    /* Create a reference symbol.
       Convert path to a sequence of symbols.
       Use last name as symbol name (with root group reference ('/') as exception).
    */
    Symbol* refsym = NULL;
    /* walk the path converting to a sequence of symbols */
    if(strcmp(text0,"/")==0) {
	/* special case of root reference */
	refsym = rootgroup;
    } else {
        List* prefix = listnew();
	/* split the text into IDENT chunks, convert to symbols */
        Symbol* container = rootgroup;
	char *ident, *p;
        char* text = strdup(text0);
	int c,lastident;
	ident=text+1; p=ident; /* skip leading '/' */
	do {
	    lastident = 0;
	    switch ((c=*p)) {
	    default: p++; break;
	    case '\\': p++; if(*p == '/') p++; break;
	    case '\0': /* treat null terminator like trailing '/' (mostly) */
		lastident=1; /* this is the last ident in the path */
		/*fall thru */
	    case '/':
		*p='\0';
		if(!lastident) {
		    unescape(ident,ident,strlen(ident),ISIDENT);
		    refsym = lookupingroup(NC_GRP,ident,container);
		    if(refsym == NULL) {
		        sprintf(errstr,"Undefined or forward referenced group: %s",ident);
		        yyerror(errstr);
			refsym = rootgroup;
		    } else {
		        listpush(prefix,(void*)refsym);
		    }
		} else { /* lastident is true */
		    unescape(ident,ident,strlen(ident),ISIDENT);
		    refsym = install(ident);
		    refsym->objectclass = NC_GRP;/* tentative */
		    refsym->ref.is_ref = 1;
		    refsym->container = container;
		    refsym->subnodes = listnew();
		}
		container = refsym;
	        ident=p+1; p=ident;
	        break;
	    }
	} while(c != '\0');
        refsym->prefix = prefix;
	free(text);
    }
    return refsym;
}

/*
Parse a simple string of digits into an unsigned long long
Return the value.
*/
static unsigned long long
parseULL(char* text, int* failp)
{
    extern int errno;
    char* endptr;
    unsigned long long uint64 = 0;

    errno = 0; endptr = NULL;
    assert(tstdecimal(text[0]));
#ifdef HAVE_STRTOULL
    uint64 = strtoull(text,&endptr,10);
    if(errno == ERANGE) {
	if(failp) *failp = ERANGE;
	return 0;
    }
#else /*!(defined HAVE_STRTOLL && defined HAVE_STRTOULL)*/
    sscanf((char*)text, "%llu", &uint64);
    /* Have no useful way to detect out of range */
#endif /*!(defined HAVE_STRTOLL && defined HAVE_STRTOULL)*/
    return uint64;
}


/**
Given the raw bits, the sign char, the tag, and hasU
fill in the appropriate *_val field
and return the type.
Note that we cannot return unsigned types if running pure netcdf classic.
The rule is to pick the smallest enclosing type.

The rule used here is that the tag (the suffix, if any)
always takes precedence and the value is modified to conform
if possible, otherwise out-of-range is signalled.
For historical reasons (ncgen3), values that fit as unsigned
are acceptable for the signed tag and conversion is attempted;
e.g. 65535s; is legal and is return as a negative short.
*/
static nc_type
downconvert(unsigned long long uint64, int* tagp, int isneg, int hasU)
{
    nc_type nct = NC_NAT;
    int tag = *tagp;
    int bit63set = (uint64 >> 63);
    long long int64 = *((long long*)&uint64);

    if(isneg && hasU) {
	return (*tagp = NC_NAT);
    }
    /* To simplify the code, we look for special case of NC_UINT64
       constants that will not fit into an NC_INT64 constant.
     */
    if(tag == NC_UINT64 && bit63set) {
        uint64_val = uint64;
	return tag;
    }
    /* At this point we need deal only with int64 value */
    /* Apply the isneg */
    if(isneg)
	int64 = - int64;

    if(tag == NC_NOTAG) {
        /* If we have no other info, then assume NC_(U)INT(64) */
	if(int64 >= NC_MIN_INT && int64 <= NC_MAX_INT) {
	    nct = (tag = NC_INT);
	    int32_val = (signed int)int64;
	} else if(int64 >= 0 && int64 <= NC_MAX_UINT) {
	        nct = (tag = NC_UINT);
	        uint32_val = (unsigned int)int64;
	} else if(int64 < 0) {
		nct = (tag = NC_INT64);
	        int64_val = (signed long long)int64;
	} else {
	        nct = (tag = NC_UINT64);
	        uint64_val = (unsigned long long)int64;
	}
        goto done;
    }
    if(isuinttype(tag) && int64 < 0)
	goto outofrange;
    switch (tag) {
    case NC_UBYTE:
	    if(int64 <= NC_MAX_UBYTE) {
	        nct = NC_UBYTE;
	        ubyte_val = (unsigned char)int64;
	    } else
		goto outofrange;
	    break;
    case NC_USHORT:
	    if(int64 <= NC_MAX_USHORT) {
	        nct = NC_USHORT;
	        uint16_val = (unsigned short)int64;
	    } else
	       goto outofrange;
	    break;
    case NC_UINT:
	    if(int64 <= NC_MAX_UINT) {
	        nct = NC_UINT;
	        uint32_val = (unsigned int)int64;
	    } else
		goto outofrange;
	    break;
    case NC_UINT64:
            if(int64 <= NC_MAX_UINT64) {
	        nct = NC_UINT64;
	        uint64_val = uint64;
	    } else
		goto outofrange;
	    break;
    case NC_INT64:
	    nct = NC_INT64;
	    int64_val = int64;
	    break;
    case NC_BYTE:
	    nct = NC_BYTE;
	    byte_val = (signed char)int64;
	    break;
    case NC_SHORT:
	    nct = NC_SHORT;
	    int16_val = (signed short)int64;
	    break;
    case NC_INT:
	    nct = NC_INT;
	    int32_val = (signed int)int64;
	    break;
    default:
	    goto outofrange;
    }

done:
    *tagp = tag;
    return nct;
outofrange:
    yyerror("Value out of range");
    return NC_NAT;
}

static int
nct2lexeme(nc_type nct)
{
    switch(nct) {
    case NC_BYTE: return BYTE_CONST;
    case NC_CHAR: return CHAR_CONST;
    case NC_SHORT: return SHORT_CONST;
    case NC_INT: return INT_CONST;
    case NC_UBYTE: return UBYTE_CONST;
    case NC_USHORT: return USHORT_CONST;
    case NC_UINT: return UINT_CONST;
    case NC_INT64: return INT64_CONST;
    case NC_UINT64: return UINT64_CONST;
    }
    return 0;
}

static int
tagmatch(nc_type nct, int tag)
{
    if(tag == NC_NAT || tag ==  NC_NOTAG)
	return 1;
    return nct == tag;
}

/* capture the tag string */
static int
collecttag(char* text, char** stagp)
{
    char* stag0;
#define MAXTAGLEN 3
    char stag[MAXTAGLEN+1];
    int slen = strlen(text);
    int staglen;
    int tag = NC_NAT;
    int hasU = 0;

    for(stag0 = text+(slen-1);stag0 > 0;stag0--) {
	if(strchr(TAGCHARS,*stag0) == NULL) {stag0++; break;}
    }
    if(stagp) *stagp = stag0;
    staglen = strlen(stag0);
    if(staglen == 0)
	return NC_NOTAG;
    if(staglen > MAXTAGLEN)
	return tag;
    strncpy(stag,stag0,sizeof(stag));
    stag[MAXTAGLEN] = '\0';
    if(stag[0] == 'U' || stag[0] == 'u') {
	hasU = 1;
        memmove(stag,stag+1,MAXTAGLEN);
	staglen--;
    } else if(stag[staglen-1] == 'U' || stag[staglen-1] == 'u') {
	hasU = 1;
	staglen--;
	stag[staglen] = '\0';
    }
    if(strlen(stag) == 0 && hasU) {
	tag = NC_UINT;
    } else if(strlen(stag) == 1) {
	switch (stag[0]) {
	case 'B': case 'b': tag = (hasU ? NC_UBYTE : NC_BYTE); break;
	case 'S': case 's': tag = (hasU ? NC_USHORT : NC_SHORT); break;
	case 'L': case 'l': tag = (hasU ? NC_UINT : NC_INT); break;
	default: break;
	}
    } else if(strcasecmp(stag,"ll") == 0) {
	tag = (hasU ? NC_UINT64 : NC_INT64);
    }
    if(tag == NC_NAT) {
	if(strlen(stag) > 0)
	    return tag;
	tag = NC_NAT;
    }
    return tag;
}

